==> zio-aws-cloudhsm_2.12-5.17.130.2-sources.jar: zio/aws/cloudhsm/model/CreateHapgResponse.scala <==
package zio.aws.cloudhsm.model
import zio.ZIO
import zio.aws.cloudhsm.model.primitives.HapgArn
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateHapgResponse(hapgArn: Option[HapgArn] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudhsm.model.CreateHapgResponse = {
    import CreateHapgResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudhsm.model.CreateHapgResponse
      .builder()
      .optionallyWith(
        hapgArn.map(value => HapgArn.unwrap(value): java.lang.String)
      )(_.hapgArn)
      .build()
  }
  def asReadOnly: zio.aws.cloudhsm.model.CreateHapgResponse.ReadOnly =
    zio.aws.cloudhsm.model.CreateHapgResponse.wrap(buildAwsValue())
}
object CreateHapgResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudhsm.model.CreateHapgResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudhsm.model.CreateHapgResponse =
      zio.aws.cloudhsm.model.CreateHapgResponse(hapgArn.map(value => value))
    def hapgArn: Option[HapgArn]
    def getHapgArn: ZIO[Any, AwsError, HapgArn] =
      AwsError.unwrapOptionField("hapgArn", hapgArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudhsm.model.CreateHapgResponse
  ) extends zio.aws.cloudhsm.model.CreateHapgResponse.ReadOnly {
    override val hapgArn: Option[HapgArn] = scala
      .Option(impl.hapgArn())
      .map(value => zio.aws.cloudhsm.model.primitives.HapgArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudhsm.model.CreateHapgResponse
  ): zio.aws.cloudhsm.model.CreateHapgResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-cloudhsm_2.12-6.20.58.3-sources.jar: zio/aws/cloudhsm/model/CreateHapgResponse.scala <==
package zio.aws.cloudhsm.model
import zio.ZIO
import zio.aws.cloudhsm.model.primitives.HapgArn
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateHapgResponse(
    hapgArn: Optional[HapgArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudhsm.model.CreateHapgResponse = {
    import CreateHapgResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudhsm.model.CreateHapgResponse
      .builder()
      .optionallyWith(
        hapgArn.map(value => HapgArn.unwrap(value): java.lang.String)
      )(_.hapgArn)
      .build()
  }
  def asReadOnly: zio.aws.cloudhsm.model.CreateHapgResponse.ReadOnly =
    zio.aws.cloudhsm.model.CreateHapgResponse.wrap(buildAwsValue())
}
object CreateHapgResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudhsm.model.CreateHapgResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudhsm.model.CreateHapgResponse =
      zio.aws.cloudhsm.model.CreateHapgResponse(hapgArn.map(value => value))
    def hapgArn: Optional[HapgArn]
    def getHapgArn: ZIO[Any, AwsError, HapgArn] =
      AwsError.unwrapOptionField("hapgArn", hapgArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudhsm.model.CreateHapgResponse
  ) extends zio.aws.cloudhsm.model.CreateHapgResponse.ReadOnly {
    override val hapgArn: Optional[HapgArn] = zio.aws.core.internal
      .optionalFromNullable(impl.hapgArn())
      .map(value => zio.aws.cloudhsm.model.primitives.HapgArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudhsm.model.CreateHapgResponse
  ): zio.aws.cloudhsm.model.CreateHapgResponse.ReadOnly = new Wrapper(impl)
}
